@@ -28,6 +28,7 @@ __all__ = (
     "BuildArtifactsTypeDef",
     "BuildNotDeletedTypeDef",
     "BuildPhaseTypeDef",
+    "BuildStatusConfigTypeDef",
     "BuildTypeDef",
     "CloudWatchLogsConfigTypeDef",
     "EnvironmentImageTypeDef",
@@ -139,6 +140,10 @@ BuildPhaseTypeDef = TypedDict(
     total=False,
 )
 
+BuildStatusConfigTypeDef = TypedDict(
+    "BuildStatusConfigTypeDef", {"context": str, "targetUrl": str}, total=False
+)
+
 BuildTypeDef = TypedDict(
     "BuildTypeDef",
     {
@@ -391,6 +396,7 @@ _OptionalProjectSourceTypeDef = TypedDict(
         "buildspec": str,
         "auth": "SourceAuthTypeDef",
         "reportBuildStatus": bool,
+        "buildStatusConfig": "BuildStatusConfigTypeDef",
         "insecureSsl": bool,
         "sourceIdentifier": str,
     },
